package com.yijia.station.service;

import java.util.List;
import com.yijia.station.domain.StationOilPriceAdjust;

/**
 * 油品调价信息Service接口
 * 
 * @author yijia
 * @date 2020-12-09
 */
public interface IStationOilPriceAdjustService 
{
    /**
     * 查询油品调价信息
     * 
     * @param adjustPriceId 油品调价信息ID
     * @return 油品调价信息
     */
    public StationOilPriceAdjust selectStationOilPriceAdjustById(Long adjustPriceId);

    /**
     * 查询油品调价信息列表
     * 
     * @param stationOilPriceAdjust 油品调价信息
     * @return 油品调价信息集合
     */
    public List<StationOilPriceAdjust> selectStationOilPriceAdjustList(StationOilPriceAdjust stationOilPriceAdjust);

    /**
     * 新增油品调价信息
     * 
     * @param stationOilPriceAdjust 油品调价信息
     * @return 结果
     */
    public int insertStationOilPriceAdjust(StationOilPriceAdjust stationOilPriceAdjust);

    /**
     * 修改油品调价信息
     * 
     * @param stationOilPriceAdjust 油品调价信息
     * @return 结果
     */
    public int updateStationOilPriceAdjust(StationOilPriceAdjust stationOilPriceAdjust);

    /**
     * 批量删除油品调价信息
     * 
     * @param adjustPriceIds 需要删除的油品调价信息ID
     * @return 结果
     */
    public int deleteStationOilPriceAdjustByIds(Long[] adjustPriceIds);

    /**
     * 删除油品调价信息信息
     * 
     * @param adjustPriceId 油品调价信息ID
     * @return 结果
     */
    public int deleteStationOilPriceAdjustById(Long adjustPriceId);
}
